CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
81 lines
3.6 KiB
C
81 lines
3.6 KiB
C
/* Minimal declarations for CUDA support. Testing purposes only. */
|
|
/* From test/CodeGenCUDA/Inputs/cuda.h. */
|
|
#include <stddef.h>
|
|
|
|
#if __HIP__ || __CUDA__
|
|
#define __constant__ __attribute__((constant))
|
|
#define __device__ __attribute__((device))
|
|
#define __global__ __attribute__((global))
|
|
#define __host__ __attribute__((host))
|
|
#define __shared__ __attribute__((shared))
|
|
#if __HIP__
|
|
#define __managed__ __attribute__((managed))
|
|
#endif
|
|
#define __launch_bounds__(...) __attribute__((launch_bounds(__VA_ARGS__)))
|
|
#define __grid_constant__ __attribute__((grid_constant))
|
|
#else
|
|
#define __constant__
|
|
#define __device__
|
|
#define __global__
|
|
#define __host__
|
|
#define __shared__
|
|
#define __managed__
|
|
#define __launch_bounds__(...)
|
|
#define __grid_constant__
|
|
#endif
|
|
|
|
struct dim3 {
|
|
unsigned x, y, z;
|
|
__host__ __device__ dim3(unsigned x, unsigned y = 1, unsigned z = 1) : x(x), y(y), z(z) {}
|
|
};
|
|
|
|
#if __HIP__ || HIP_PLATFORM
|
|
typedef struct hipStream *hipStream_t;
|
|
typedef enum hipError {} hipError_t;
|
|
int hipConfigureCall(dim3 gridSize, dim3 blockSize, size_t sharedSize = 0,
|
|
hipStream_t stream = 0);
|
|
extern "C" hipError_t __hipPushCallConfiguration(dim3 gridSize, dim3 blockSize,
|
|
size_t sharedSize = 0,
|
|
hipStream_t stream = 0);
|
|
extern "C" int __hipPopCallConfiguration(dim3 *gridSize, dim3 *blockSize,
|
|
size_t *sharedSize,
|
|
hipStream_t *stream);
|
|
#ifndef __HIP_API_PER_THREAD_DEFAULT_STREAM__
|
|
extern "C" hipError_t hipLaunchKernel(const void *func, dim3 gridDim,
|
|
dim3 blockDim, void **args,
|
|
size_t sharedMem,
|
|
hipStream_t stream);
|
|
#else
|
|
extern "C" hipError_t hipLaunchKernel_spt(const void *func, dim3 gridDim,
|
|
dim3 blockDim, void **args,
|
|
size_t sharedMem,
|
|
hipStream_t stream);
|
|
#endif // __HIP_API_PER_THREAD_DEFAULT_STREAM__
|
|
#elif __OFFLOAD_VIA_LLVM__
|
|
extern "C" unsigned __llvmPushCallConfiguration(dim3 gridDim, dim3 blockDim,
|
|
size_t sharedMem = 0, void *stream = 0);
|
|
extern "C" unsigned llvmLaunchKernel(const void *func, dim3 gridDim, dim3 blockDim,
|
|
void **args, size_t sharedMem = 0, void *stream = 0);
|
|
#else
|
|
typedef struct cudaStream *cudaStream_t;
|
|
typedef enum cudaError {} cudaError_t;
|
|
extern "C" int cudaConfigureCall(dim3 gridSize, dim3 blockSize,
|
|
size_t sharedSize = 0,
|
|
cudaStream_t stream = 0);
|
|
extern "C" int __cudaPushCallConfiguration(dim3 gridSize, dim3 blockSize,
|
|
size_t sharedSize = 0,
|
|
cudaStream_t stream = 0);
|
|
extern "C" int __cudaPopCallConfiguration(dim3 *gridSize, dim3 *blockSize,
|
|
size_t *sharedSize,
|
|
cudaStream_t *stream);
|
|
extern "C" cudaError_t cudaLaunchKernel(const void *func, dim3 gridDim,
|
|
dim3 blockDim, void **args,
|
|
size_t sharedMem, cudaStream_t stream);
|
|
extern "C" cudaError_t cudaLaunchKernel_ptsz(const void *func, dim3 gridDim,
|
|
dim3 blockDim, void **args,
|
|
size_t sharedMem, cudaStream_t stream);
|
|
|
|
#endif
|
|
|
|
extern "C" __device__ int printf(const char*, ...);
|